# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: degiro_connector/trading/models/trading.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='degiro_connector/trading/models/trading.proto',
  package='degiro_connector.trading',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-degiro_connector/trading/models/trading.proto\x12\x18\x64\x65giro_connector.trading\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x8b\x01\n\x0b\x43redentials\x12\x13\n\x0bint_account\x18\x01 \x01(\x05\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\x12\x19\n\x0ftotp_secret_key\x18\x04 \x01(\tH\x00\x12\x1b\n\x11one_time_password\x18\x05 \x01(\x05H\x00\x42\x0b\n\toneof_2fa\"\x94\n\n\x05Order\x12\x36\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32&.degiro_connector.trading.Order.Action\x12\n\n\x02id\x18\x02 \x01(\t\x12=\n\norder_type\x18\x03 \x01(\x0e\x32).degiro_connector.trading.Order.OrderType\x12\r\n\x05price\x18\x04 \x01(\x01\x12\x12\n\nstop_price\x18\x05 \x01(\x01\x12\x12\n\nproduct_id\x18\x06 \x01(\x05\x12\x0c\n\x04size\x18\x07 \x01(\x01\x12;\n\ttime_type\x18\x08 \x01(\x0e\x32(.degiro_connector.trading.Order.TimeType\x12\x15\n\rcontract_size\x18\t \x01(\x01\x12\x15\n\rcontract_type\x18\n \x01(\x05\x12\x10\n\x08\x63urrency\x18\x0b \x01(\t\x12\x0c\n\x04hour\x18\x0c \x01(\t\x12\x14\n\x0cis_deletable\x18\r \x01(\x08\x12\x15\n\ris_modifiable\x18\x0e \x01(\x08\x12\x0f\n\x07product\x18\x0f \x01(\t\x12\x10\n\x08quantity\x18\x10 \x01(\x01\x12\x19\n\x11total_order_value\x18\x11 \x01(\x01\x12\x16\n\x0eretained_order\x18\x12 \x01(\x08\x12\x18\n\x10sent_to_exchange\x18\x13 \x01(\x08\x1a\x84\x04\n\x10\x43heckingResponse\x12\x17\n\x0f\x63onfirmation_id\x18\x01 \x01(\t\x12\x16\n\x0e\x66ree_space_new\x18\x02 \x01(\x01\x12\x35\n\x11response_datetime\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\x10transaction_fees\x18\x04 \x03(\x0b\x32\x17.google.protobuf.Struct\x12:\n\x19transaction_opposite_fees\x18\x05 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x32\n\x11transaction_taxes\x18\x06 \x03(\x0b\x32\x17.google.protobuf.Struct\x12?\n\x1etransaction_auto_fx_surcharges\x18\x07 \x03(\x0b\x32\x17.google.protobuf.Struct\x12H\n\'transaction_auto_fx_opposite_surcharges\x18\x08 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x1f\n\x17\x61uto_fx_conversion_rate\x18\t \x01(\x01\x12\x17\n\x0ftransaction_fee\x18\n \x01(\x01\x12 \n\x18show_ex_ante_report_link\x18\x0b \x01(\x08\x1a_\n\x14\x43onfirmationResponse\x12\x10\n\x08order_id\x18\x01 \x01(\t\x12\x35\n\x11response_datetime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x1b\n\x06\x41\x63tion\x12\x07\n\x03\x42UY\x10\x00\x12\x08\n\x04SELL\x10\x01\"A\n\tOrderType\x12\t\n\x05LIMIT\x10\x00\x12\x0e\n\nSTOP_LIMIT\x10\x01\x12\n\n\x06MARKET\x10\x02\x12\r\n\tSTOP_LOSS\x10\x03\"S\n\x08TimeType\x12\r\n\tUNKNOWN_0\x10\x00\x12\x11\n\rGOOD_TILL_DAY\x10\x01\x12\r\n\tUNKNOWN_2\x10\x02\x12\x16\n\x12GOOD_TILL_CANCELED\x10\x03\"\xd9\n\n\x06Update\x12\x35\n\x11response_datetime\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\x06\x61lerts\x18\x02 \x01(\x0b\x32\'.degiro_connector.trading.Update.Alerts\x12>\n\ncash_funds\x18\x03 \x01(\x0b\x32*.degiro_connector.trading.Update.CashFunds\x12L\n\x11historical_orders\x18\x04 \x01(\x0b\x32\x31.degiro_connector.trading.Update.HistoricalOrders\x12\x37\n\x06orders\x18\x05 \x01(\x0b\x32\'.degiro_connector.trading.Update.Orders\x12=\n\tportfolio\x18\x06 \x01(\x0b\x32*.degiro_connector.trading.Update.Portfolio\x12H\n\x0ftotal_portfolio\x18\x07 \x01(\x0b\x32/.degiro_connector.trading.Update.TotalPortfolio\x12\x43\n\x0ctransactions\x18\x08 \x01(\x0b\x32-.degiro_connector.trading.Update.Transactions\x1aX\n\x07Request\x12\x37\n\x06option\x18\x01 \x01(\x0e\x32\'.degiro_connector.trading.Update.Option\x12\x14\n\x0clast_updated\x18\x02 \x01(\x05\x1aG\n\x0bRequestList\x12\x38\n\x06values\x18\x01 \x03(\x0b\x32(.degiro_connector.trading.Update.Request\x1aG\n\x06\x41lerts\x12\x14\n\x0clast_updated\x18\x01 \x01(\x05\x12\'\n\x06values\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x1aJ\n\tCashFunds\x12\x14\n\x0clast_updated\x18\x01 \x01(\x05\x12\'\n\x06values\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x1aY\n\x10HistoricalOrders\x12\x14\n\x0clast_updated\x18\x01 \x01(\x05\x12/\n\x06values\x18\x02 \x03(\x0b\x32\x1f.degiro_connector.trading.Order\x1aO\n\x06Orders\x12\x14\n\x0clast_updated\x18\x01 \x01(\x05\x12/\n\x06values\x18\x02 \x03(\x0b\x32\x1f.degiro_connector.trading.Order\x1aJ\n\tPortfolio\x12\x14\n\x0clast_updated\x18\x01 \x01(\x05\x12\'\n\x06values\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct\x1aO\n\x0eTotalPortfolio\x12\x14\n\x0clast_updated\x18\x01 \x01(\x05\x12\'\n\x06values\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x1aM\n\x0cTransactions\x12\x14\n\x0clast_updated\x18\x01 \x01(\x05\x12\'\n\x06values\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct\"z\n\x06Option\x12\n\n\x06\x41LERTS\x10\x00\x12\r\n\tCASHFUNDS\x10\x01\x12\x14\n\x10HISTORICALORDERS\x10\x02\x12\n\n\x06ORDERS\x10\x03\x12\r\n\tPORTFOLIO\x10\x04\x12\x12\n\x0eTOTALPORTFOLIO\x10\x05\x12\x10\n\x0cTRANSACTIONS\x10\x06\"\xbd\x02\n\rOrdersHistory\x12\'\n\x06values\x18\x01 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x35\n\x11response_datetime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\xcb\x01\n\x07Request\x12G\n\tfrom_date\x18\x01 \x01(\x0b\x32\x34.degiro_connector.trading.OrdersHistory.Request.Date\x12\x45\n\x07to_date\x18\x02 \x01(\x0b\x32\x34.degiro_connector.trading.OrdersHistory.Request.Date\x1a\x30\n\x04\x44\x61te\x12\x0c\n\x04year\x18\x01 \x01(\x05\x12\r\n\x05month\x18\x02 \x01(\x05\x12\x0b\n\x03\x64\x61y\x18\x03 \x01(\x05\"\xf4\x02\n\x13TransactionsHistory\x12\'\n\x06values\x18\x01 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x35\n\x11response_datetime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\xfc\x01\n\x07Request\x12M\n\tfrom_date\x18\x01 \x01(\x0b\x32:.degiro_connector.trading.TransactionsHistory.Request.Date\x12K\n\x07to_date\x18\x02 \x01(\x0b\x32:.degiro_connector.trading.TransactionsHistory.Request.Date\x12#\n\x1bgroup_transactions_by_order\x18\x03 \x01(\x08\x1a\x30\n\x04\x44\x61te\x12\x0c\n\x04year\x18\x01 \x01(\x05\x12\r\n\x05month\x18\x02 \x01(\x05\x12\x0b\n\x03\x64\x61y\x18\x03 \x01(\x05\"\xc3\x02\n\x0f\x41\x63\x63ountOverview\x12\'\n\x06values\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x35\n\x11response_datetime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\xcf\x01\n\x07Request\x12I\n\tfrom_date\x18\x01 \x01(\x0b\x32\x36.degiro_connector.trading.AccountOverview.Request.Date\x12G\n\x07to_date\x18\x02 \x01(\x0b\x32\x36.degiro_connector.trading.AccountOverview.Request.Date\x1a\x30\n\x04\x44\x61te\x12\x0c\n\x04year\x18\x01 \x01(\x05\x12\r\n\x05month\x18\x02 \x01(\x05\x12\x0b\n\x03\x64\x61y\x18\x03 \x01(\x05\"\xc5\x0e\n\rProductSearch\x12\x0e\n\x06offset\x18\x01 \x01(\x05\x12)\n\x08products\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x35\n\x11response_datetime\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05total\x18\x04 \x01(\x05\x1a\x31\n\x06\x43onfig\x12\'\n\x06values\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x1a\xba\x01\n\x0cRequestBonds\x12\x1b\n\x13\x62ond_issuer_type_id\x18\x01 \x01(\x05\x12\x18\n\x10\x62ond_exchange_id\x18\x02 \x01(\x05\x12\x13\n\x0bsearch_text\x18\x03 \x01(\t\x12\x0e\n\x06offset\x18\x04 \x01(\x05\x12\r\n\x05limit\x18\x05 \x01(\x05\x12\x15\n\rrequire_total\x18\x06 \x01(\x08\x12\x14\n\x0csort_columns\x18\x07 \x01(\t\x12\x12\n\nsort_types\x18\x08 \x01(\t\x1a\xd7\x01\n\x0bRequestETFs\x12\x14\n\x0cpopular_only\x18\x01 \x01(\x08\x12\x1d\n\x15input_aggregate_types\x18\x02 \x01(\t\x12\x1e\n\x16input_aggregate_values\x18\x03 \x01(\t\x12\x13\n\x0bsearch_text\x18\x04 \x01(\t\x12\x0e\n\x06offset\x18\x05 \x01(\x05\x12\r\n\x05limit\x18\x06 \x01(\x05\x12\x15\n\rrequire_total\x18\x07 \x01(\x08\x12\x14\n\x0csort_columns\x18\x08 \x01(\t\x12\x12\n\nsort_types\x18\t \x01(\t\x1a\x83\x01\n\x0cRequestFunds\x12\x13\n\x0bsearch_text\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\x12\x15\n\rrequire_total\x18\x04 \x01(\x08\x12\x14\n\x0csort_columns\x18\x05 \x01(\t\x12\x12\n\nsort_types\x18\x06 \x01(\t\x1a\xba\x01\n\x0eRequestFutures\x12\x1a\n\x12\x66uture_exchange_id\x18\x01 \x01(\x05\x12\x17\n\x0funderlying_isin\x18\x02 \x01(\t\x12\x13\n\x0bsearch_text\x18\x03 \x01(\t\x12\x0e\n\x06offset\x18\x04 \x01(\x05\x12\r\n\x05limit\x18\x05 \x01(\x05\x12\x15\n\rrequire_total\x18\x06 \x01(\x08\x12\x14\n\x0csort_columns\x18\x07 \x01(\t\x12\x12\n\nsort_types\x18\x08 \x01(\t\x1a\xdd\x01\n\x11RequestLeverageds\x12\x14\n\x0cpopular_only\x18\x01 \x01(\x08\x12\x1d\n\x15input_aggregate_types\x18\x02 \x01(\t\x12\x1e\n\x16input_aggregate_values\x18\x03 \x01(\t\x12\x13\n\x0bsearch_text\x18\x04 \x01(\t\x12\x0e\n\x06offset\x18\x05 \x01(\x05\x12\r\n\x05limit\x18\x06 \x01(\x05\x12\x15\n\rrequire_total\x18\x07 \x01(\x08\x12\x14\n\x0csort_columns\x18\x08 \x01(\t\x12\x12\n\nsort_types\x18\t \x01(\t\x1a\\\n\rRequestLookup\x12\x13\n\x0bsearch_text\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x0e\n\x06offset\x18\x03 \x01(\x05\x12\x17\n\x0fproduct_type_id\x18\x04 \x01(\x05\x1a\xf9\x01\n\x0eRequestOptions\x12\x1d\n\x15input_aggregate_types\x18\x01 \x01(\t\x12\x1e\n\x16input_aggregate_values\x18\x02 \x01(\t\x12\x1a\n\x12option_exchange_id\x18\x03 \x01(\x05\x12\x17\n\x0funderlying_isin\x18\x04 \x01(\t\x12\x13\n\x0bsearch_text\x18\x05 \x01(\t\x12\x0e\n\x06offset\x18\x06 \x01(\x05\x12\r\n\x05limit\x18\x07 \x01(\x05\x12\x15\n\rrequire_total\x18\x08 \x01(\x08\x12\x14\n\x0csort_columns\x18\t \x01(\t\x12\x12\n\nsort_types\x18\n \x01(\t\x1a\xe2\x01\n\rRequestStocks\x12\x1b\n\x13is_in_us_green_list\x18\x01 \x01(\x08\x12\x10\n\x08index_id\x18\x02 \x01(\x05\x12\x13\n\x0b\x65xchange_id\x18\x03 \x01(\x05\x12\x18\n\x10stock_country_id\x18\x04 \x01(\x05\x12\x13\n\x0bsearch_text\x18\x05 \x01(\t\x12\x0e\n\x06offset\x18\x06 \x01(\x05\x12\r\n\x05limit\x18\x07 \x01(\x05\x12\x15\n\rrequire_total\x18\x08 \x01(\x08\x12\x14\n\x0csort_columns\x18\t \x01(\t\x12\x12\n\nsort_types\x18\n \x01(\t\x1a\x86\x01\n\x0fRequestWarrants\x12\x13\n\x0bsearch_text\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\x12\x15\n\rrequire_total\x18\x04 \x01(\x08\x12\x14\n\x0csort_columns\x18\x05 \x01(\t\x12\x12\n\nsort_types\x18\x06 \x01(\t\"\xc9\x01\n\nFavourites\x12\x39\n\x06values\x18\x01 \x03(\x0b\x32).degiro_connector.trading.Favourites.List\x12\x35\n\x11response_datetime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1aI\n\x04List\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nis_default\x18\x03 \x01(\x08\x12\x13\n\x0bproduct_ids\x18\x04 \x03(\x05\"T\n\x0cProductsInfo\x12\'\n\x06values\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x1a\x1b\n\x07Request\x12\x10\n\x08products\x18\x01 \x03(\x05\"8\n\rCompanyRatios\x12\'\n\x06values\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"9\n\x0e\x43ompanyProfile\x12\'\n\x06values\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\">\n\x13\x46inancialStatements\x12\'\n\x06values\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"\x90\x01\n\nLatestNews\x12&\n\x05items\x18\x01 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05total\x18\x03 \x01(\x05\x1a;\n\x07Request\x12\x0e\n\x06offset\x18\x01 \x01(\x05\x12\x11\n\tlanguages\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x05\"W\n\x0eTopNewsPreview\x12&\n\x05items\x18\x01 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05total\x18\x03 \x01(\x05\"\xa1\x01\n\rNewsByCompany\x12&\n\x05items\x18\x01 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05total\x18\x03 \x01(\x05\x1aI\n\x07Request\x12\x0c\n\x04isin\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x0e\n\x06offset\x18\x03 \x01(\x05\x12\x11\n\tlanguages\x18\x04 \x01(\t\"\x87\x04\n\x11\x43\x61shAccountReport\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x42\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\x32.degiro_connector.trading.CashAccountReport.Format\x12\x35\n\x11response_datetime\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\xb6\x02\n\x07Request\x12\x42\n\x06\x66ormat\x18\x01 \x01(\x0e\x32\x32.degiro_connector.trading.CashAccountReport.Format\x12\x0f\n\x07\x63ountry\x18\x02 \x01(\t\x12\x0c\n\x04lang\x18\x03 \x01(\t\x12K\n\tfrom_date\x18\x04 \x01(\x0b\x32\x38.degiro_connector.trading.CashAccountReport.Request.Date\x12I\n\x07to_date\x18\x05 \x01(\x0b\x32\x38.degiro_connector.trading.CashAccountReport.Request.Date\x1a\x30\n\x04\x44\x61te\x12\x0c\n\x04year\x18\x01 \x01(\x05\x12\r\n\x05month\x18\x02 \x01(\x05\x12\x0b\n\x03\x64\x61y\x18\x03 \x01(\x05\"-\n\x06\x46ormat\x12\x07\n\x03\x43SV\x10\x00\x12\x08\n\x04HTML\x10\x01\x12\x07\n\x03PDF\x10\x02\x12\x07\n\x03XLS\x10\x03\"\x95\x05\n\x06\x41genda\x12\x44\n\rcalendar_type\x18\x01 \x01(\x0e\x32-.degiro_connector.trading.Agenda.CalendarType\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06offset\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\x12\x35\n\x11response_datetime\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\xb4\x02\n\x07Request\x12\x44\n\rcalendar_type\x18\x01 \x01(\x0e\x32-.degiro_connector.trading.Agenda.CalendarType\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\x12\x15\n\rorder_by_desc\x18\x04 \x01(\x08\x12.\n\nstart_date\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_date\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0c\x63ompany_name\x18\x07 \x01(\t\x12\x11\n\tcountries\x18\x08 \x01(\t\x12\x17\n\x0f\x63lassifications\x18\t \x01(\t\x12\r\n\x05units\x18\n \x01(\t\"\x8f\x01\n\x0c\x43\x61lendarType\x12\x15\n\x11\x44IVIDEND_CALENDAR\x10\x00\x12\x15\n\x11\x45\x43ONOMIC_CALENDAR\x10\x01\x12\x15\n\x11\x45\x41RNINGS_CALENDAR\x10\x02\x12\x14\n\x10HOLIDAY_CALENDAR\x10\x03\x12\x10\n\x0cIPO_CALENDAR\x10\x04\x12\x12\n\x0eSPLIT_CALENDAR\x10\x05\"\xcc\x01\n\x12\x45stimatesSummaries\x12\'\n\x06\x61nnual\x18\x01 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x10\n\x08\x63urrency\x18\x02 \x01(\t\x12(\n\x07interim\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x15\n\rlastRetrieved\x18\x04 \x01(\t\x12\x13\n\x0blastUpdated\x18\x05 \x01(\t\x12\x18\n\x10preferredMeasure\x18\x06 \x01(\t\x12\x0b\n\x03ric\x18\x07 \x01(\t\"\xae\x03\n\x0ePositionReport\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12?\n\x06\x66ormat\x18\x02 \x01(\x0e\x32/.degiro_connector.trading.PositionReport.Format\x12\x35\n\x11response_datetime\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\xe3\x01\n\x07Request\x12?\n\x06\x66ormat\x18\x01 \x01(\x0e\x32/.degiro_connector.trading.PositionReport.Format\x12\x0f\n\x07\x63ountry\x18\x02 \x01(\t\x12\x0c\n\x04lang\x18\x03 \x01(\t\x12\x46\n\x07to_date\x18\x05 \x01(\x0b\x32\x35.degiro_connector.trading.PositionReport.Request.Date\x1a\x30\n\x04\x44\x61te\x12\x0c\n\x04year\x18\x01 \x01(\x05\x12\r\n\x05month\x18\x02 \x01(\x05\x12\x0b\n\x03\x64\x61y\x18\x03 \x01(\x05\"-\n\x06\x46ormat\x12\x07\n\x03\x43SV\x10\x00\x12\x08\n\x04HTML\x10\x01\x12\x07\n\x03PDF\x10\x02\x12\x07\n\x03XLS\x10\x03\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_ORDER_ACTION = _descriptor.EnumDescriptor(
  name='Action',
  full_name='degiro_connector.trading.Order.Action',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BUY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SELL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1402,
  serialized_end=1429,
)
_sym_db.RegisterEnumDescriptor(_ORDER_ACTION)

_ORDER_ORDERTYPE = _descriptor.EnumDescriptor(
  name='OrderType',
  full_name='degiro_connector.trading.Order.OrderType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LIMIT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_LIMIT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MARKET', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_LOSS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1431,
  serialized_end=1496,
)
_sym_db.RegisterEnumDescriptor(_ORDER_ORDERTYPE)

_ORDER_TIMETYPE = _descriptor.EnumDescriptor(
  name='TimeType',
  full_name='degiro_connector.trading.Order.TimeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_0', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GOOD_TILL_DAY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_2', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GOOD_TILL_CANCELED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1498,
  serialized_end=1581,
)
_sym_db.RegisterEnumDescriptor(_ORDER_TIMETYPE)

_UPDATE_OPTION = _descriptor.EnumDescriptor(
  name='Option',
  full_name='degiro_connector.trading.Update.Option',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ALERTS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CASHFUNDS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HISTORICALORDERS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ORDERS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORTFOLIO', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TOTALPORTFOLIO', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRANSACTIONS', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2831,
  serialized_end=2953,
)
_sym_db.RegisterEnumDescriptor(_UPDATE_OPTION)

_CASHACCOUNTREPORT_FORMAT = _descriptor.EnumDescriptor(
  name='Format',
  full_name='degiro_connector.trading.CashAccountReport.Format',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CSV', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTML', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PDF', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='XLS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7186,
  serialized_end=7231,
)
_sym_db.RegisterEnumDescriptor(_CASHACCOUNTREPORT_FORMAT)

_AGENDA_CALENDARTYPE = _descriptor.EnumDescriptor(
  name='CalendarType',
  full_name='degiro_connector.trading.Agenda.CalendarType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DIVIDEND_CALENDAR', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ECONOMIC_CALENDAR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EARNINGS_CALENDAR', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HOLIDAY_CALENDAR', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IPO_CALENDAR', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPLIT_CALENDAR', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7752,
  serialized_end=7895,
)
_sym_db.RegisterEnumDescriptor(_AGENDA_CALENDARTYPE)

_POSITIONREPORT_FORMAT = _descriptor.EnumDescriptor(
  name='Format',
  full_name='degiro_connector.trading.PositionReport.Format',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CSV', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTML', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PDF', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='XLS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7186,
  serialized_end=7231,
)
_sym_db.RegisterEnumDescriptor(_POSITIONREPORT_FORMAT)


_CREDENTIALS = _descriptor.Descriptor(
  name='Credentials',
  full_name='degiro_connector.trading.Credentials',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='int_account', full_name='degiro_connector.trading.Credentials.int_account', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='username', full_name='degiro_connector.trading.Credentials.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='degiro_connector.trading.Credentials.password', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totp_secret_key', full_name='degiro_connector.trading.Credentials.totp_secret_key', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='one_time_password', full_name='degiro_connector.trading.Credentials.one_time_password', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='oneof_2fa', full_name='degiro_connector.trading.Credentials.oneof_2fa',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=139,
  serialized_end=278,
)


_ORDER_CHECKINGRESPONSE = _descriptor.Descriptor(
  name='CheckingResponse',
  full_name='degiro_connector.trading.Order.CheckingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='confirmation_id', full_name='degiro_connector.trading.Order.CheckingResponse.confirmation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='free_space_new', full_name='degiro_connector.trading.Order.CheckingResponse.free_space_new', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_datetime', full_name='degiro_connector.trading.Order.CheckingResponse.response_datetime', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transaction_fees', full_name='degiro_connector.trading.Order.CheckingResponse.transaction_fees', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transaction_opposite_fees', full_name='degiro_connector.trading.Order.CheckingResponse.transaction_opposite_fees', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transaction_taxes', full_name='degiro_connector.trading.Order.CheckingResponse.transaction_taxes', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transaction_auto_fx_surcharges', full_name='degiro_connector.trading.Order.CheckingResponse.transaction_auto_fx_surcharges', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transaction_auto_fx_opposite_surcharges', full_name='degiro_connector.trading.Order.CheckingResponse.transaction_auto_fx_opposite_surcharges', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_fx_conversion_rate', full_name='degiro_connector.trading.Order.CheckingResponse.auto_fx_conversion_rate', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transaction_fee', full_name='degiro_connector.trading.Order.CheckingResponse.transaction_fee', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='show_ex_ante_report_link', full_name='degiro_connector.trading.Order.CheckingResponse.show_ex_ante_report_link', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=787,
  serialized_end=1303,
)

_ORDER_CONFIRMATIONRESPONSE = _descriptor.Descriptor(
  name='ConfirmationResponse',
  full_name='degiro_connector.trading.Order.ConfirmationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_id', full_name='degiro_connector.trading.Order.ConfirmationResponse.order_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_datetime', full_name='degiro_connector.trading.Order.ConfirmationResponse.response_datetime', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1305,
  serialized_end=1400,
)

_ORDER = _descriptor.Descriptor(
  name='Order',
  full_name='degiro_connector.trading.Order',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='degiro_connector.trading.Order.action', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='degiro_connector.trading.Order.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_type', full_name='degiro_connector.trading.Order.order_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='degiro_connector.trading.Order.price', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_price', full_name='degiro_connector.trading.Order.stop_price', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='product_id', full_name='degiro_connector.trading.Order.product_id', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='degiro_connector.trading.Order.size', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_type', full_name='degiro_connector.trading.Order.time_type', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contract_size', full_name='degiro_connector.trading.Order.contract_size', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contract_type', full_name='degiro_connector.trading.Order.contract_type', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currency', full_name='degiro_connector.trading.Order.currency', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hour', full_name='degiro_connector.trading.Order.hour', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_deletable', full_name='degiro_connector.trading.Order.is_deletable', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_modifiable', full_name='degiro_connector.trading.Order.is_modifiable', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='product', full_name='degiro_connector.trading.Order.product', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='degiro_connector.trading.Order.quantity', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_order_value', full_name='degiro_connector.trading.Order.total_order_value', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retained_order', full_name='degiro_connector.trading.Order.retained_order', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sent_to_exchange', full_name='degiro_connector.trading.Order.sent_to_exchange', index=18,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ORDER_CHECKINGRESPONSE, _ORDER_CONFIRMATIONRESPONSE, ],
  enum_types=[
    _ORDER_ACTION,
    _ORDER_ORDERTYPE,
    _ORDER_TIMETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=281,
  serialized_end=1581,
)


_UPDATE_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='degiro_connector.trading.Update.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='option', full_name='degiro_connector.trading.Update.Request.option', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='degiro_connector.trading.Update.Request.last_updated', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2111,
  serialized_end=2199,
)

_UPDATE_REQUESTLIST = _descriptor.Descriptor(
  name='RequestList',
  full_name='degiro_connector.trading.Update.RequestList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='degiro_connector.trading.Update.RequestList.values', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2201,
  serialized_end=2272,
)

_UPDATE_ALERTS = _descriptor.Descriptor(
  name='Alerts',
  full_name='degiro_connector.trading.Update.Alerts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='degiro_connector.trading.Update.Alerts.last_updated', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='degiro_connector.trading.Update.Alerts.values', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2274,
  serialized_end=2345,
)

_UPDATE_CASHFUNDS = _descriptor.Descriptor(
  name='CashFunds',
  full_name='degiro_connector.trading.Update.CashFunds',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='degiro_connector.trading.Update.CashFunds.last_updated', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='degiro_connector.trading.Update.CashFunds.values', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2347,
  serialized_end=2421,
)

_UPDATE_HISTORICALORDERS = _descriptor.Descriptor(
  name='HistoricalOrders',
  full_name='degiro_connector.trading.Update.HistoricalOrders',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='degiro_connector.trading.Update.HistoricalOrders.last_updated', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='degiro_connector.trading.Update.HistoricalOrders.values', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2423,
  serialized_end=2512,
)

_UPDATE_ORDERS = _descriptor.Descriptor(
  name='Orders',
  full_name='degiro_connector.trading.Update.Orders',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='degiro_connector.trading.Update.Orders.last_updated', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='degiro_connector.trading.Update.Orders.values', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2514,
  serialized_end=2593,
)

_UPDATE_PORTFOLIO = _descriptor.Descriptor(
  name='Portfolio',
  full_name='degiro_connector.trading.Update.Portfolio',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='degiro_connector.trading.Update.Portfolio.last_updated', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='degiro_connector.trading.Update.Portfolio.values', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2595,
  serialized_end=2669,
)

_UPDATE_TOTALPORTFOLIO = _descriptor.Descriptor(
  name='TotalPortfolio',
  full_name='degiro_connector.trading.Update.TotalPortfolio',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='degiro_connector.trading.Update.TotalPortfolio.last_updated', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='degiro_connector.trading.Update.TotalPortfolio.values', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2671,
  serialized_end=2750,
)

_UPDATE_TRANSACTIONS = _descriptor.Descriptor(
  name='Transactions',
  full_name='degiro_connector.trading.Update.Transactions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='degiro_connector.trading.Update.Transactions.last_updated', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='degiro_connector.trading.Update.Transactions.values', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2752,
  serialized_end=2829,
)

_UPDATE = _descriptor.Descriptor(
  name='Update',
  full_name='degiro_connector.trading.Update',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='response_datetime', full_name='degiro_connector.trading.Update.response_datetime', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alerts', full_name='degiro_connector.trading.Update.alerts', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cash_funds', full_name='degiro_connector.trading.Update.cash_funds', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='historical_orders', full_name='degiro_connector.trading.Update.historical_orders', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orders', full_name='degiro_connector.trading.Update.orders', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='portfolio', full_name='degiro_connector.trading.Update.portfolio', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_portfolio', full_name='degiro_connector.trading.Update.total_portfolio', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transactions', full_name='degiro_connector.trading.Update.transactions', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATE_REQUEST, _UPDATE_REQUESTLIST, _UPDATE_ALERTS, _UPDATE_CASHFUNDS, _UPDATE_HISTORICALORDERS, _UPDATE_ORDERS, _UPDATE_PORTFOLIO, _UPDATE_TOTALPORTFOLIO, _UPDATE_TRANSACTIONS, ],
  enum_types=[
    _UPDATE_OPTION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1584,
  serialized_end=2953,
)


_ORDERSHISTORY_REQUEST_DATE = _descriptor.Descriptor(
  name='Date',
  full_name='degiro_connector.trading.OrdersHistory.Request.Date',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='year', full_name='degiro_connector.trading.OrdersHistory.Request.Date.year', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='month', full_name='degiro_connector.trading.OrdersHistory.Request.Date.month', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='day', full_name='degiro_connector.trading.OrdersHistory.Request.Date.day', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3225,
  serialized_end=3273,
)

_ORDERSHISTORY_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='degiro_connector.trading.OrdersHistory.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_date', full_name='degiro_connector.trading.OrdersHistory.Request.from_date', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_date', full_name='degiro_connector.trading.OrdersHistory.Request.to_date', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ORDERSHISTORY_REQUEST_DATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3070,
  serialized_end=3273,
)

_ORDERSHISTORY = _descriptor.Descriptor(
  name='OrdersHistory',
  full_name='degiro_connector.trading.OrdersHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='degiro_connector.trading.OrdersHistory.values', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_datetime', full_name='degiro_connector.trading.OrdersHistory.response_datetime', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ORDERSHISTORY_REQUEST, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2956,
  serialized_end=3273,
)


_TRANSACTIONSHISTORY_REQUEST_DATE = _descriptor.Descriptor(
  name='Date',
  full_name='degiro_connector.trading.TransactionsHistory.Request.Date',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='year', full_name='degiro_connector.trading.TransactionsHistory.Request.Date.year', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='month', full_name='degiro_connector.trading.TransactionsHistory.Request.Date.month', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='day', full_name='degiro_connector.trading.TransactionsHistory.Request.Date.day', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3225,
  serialized_end=3273,
)

_TRANSACTIONSHISTORY_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='degiro_connector.trading.TransactionsHistory.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_date', full_name='degiro_connector.trading.TransactionsHistory.Request.from_date', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_date', full_name='degiro_connector.trading.TransactionsHistory.Request.to_date', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_transactions_by_order', full_name='degiro_connector.trading.TransactionsHistory.Request.group_transactions_by_order', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TRANSACTIONSHISTORY_REQUEST_DATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3396,
  serialized_end=3648,
)

_TRANSACTIONSHISTORY = _descriptor.Descriptor(
  name='TransactionsHistory',
  full_name='degiro_connector.trading.TransactionsHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='degiro_connector.trading.TransactionsHistory.values', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_datetime', full_name='degiro_connector.trading.TransactionsHistory.response_datetime', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TRANSACTIONSHISTORY_REQUEST, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3276,
  serialized_end=3648,
)


_ACCOUNTOVERVIEW_REQUEST_DATE = _descriptor.Descriptor(
  name='Date',
  full_name='degiro_connector.trading.AccountOverview.Request.Date',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='year', full_name='degiro_connector.trading.AccountOverview.Request.Date.year', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='month', full_name='degiro_connector.trading.AccountOverview.Request.Date.month', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='day', full_name='degiro_connector.trading.AccountOverview.Request.Date.day', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3225,
  serialized_end=3273,
)

_ACCOUNTOVERVIEW_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='degiro_connector.trading.AccountOverview.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_date', full_name='degiro_connector.trading.AccountOverview.Request.from_date', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_date', full_name='degiro_connector.trading.AccountOverview.Request.to_date', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ACCOUNTOVERVIEW_REQUEST_DATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3767,
  serialized_end=3974,
)

_ACCOUNTOVERVIEW = _descriptor.Descriptor(
  name='AccountOverview',
  full_name='degiro_connector.trading.AccountOverview',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='degiro_connector.trading.AccountOverview.values', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_datetime', full_name='degiro_connector.trading.AccountOverview.response_datetime', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ACCOUNTOVERVIEW_REQUEST, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3651,
  serialized_end=3974,
)


_PRODUCTSEARCH_CONFIG = _descriptor.Descriptor(
  name='Config',
  full_name='degiro_connector.trading.ProductSearch.Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='degiro_connector.trading.ProductSearch.Config.values', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4123,
  serialized_end=4172,
)

_PRODUCTSEARCH_REQUESTBONDS = _descriptor.Descriptor(
  name='RequestBonds',
  full_name='degiro_connector.trading.ProductSearch.RequestBonds',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bond_issuer_type_id', full_name='degiro_connector.trading.ProductSearch.RequestBonds.bond_issuer_type_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bond_exchange_id', full_name='degiro_connector.trading.ProductSearch.RequestBonds.bond_exchange_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='search_text', full_name='degiro_connector.trading.ProductSearch.RequestBonds.search_text', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='degiro_connector.trading.ProductSearch.RequestBonds.offset', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='degiro_connector.trading.ProductSearch.RequestBonds.limit', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='require_total', full_name='degiro_connector.trading.ProductSearch.RequestBonds.require_total', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sort_columns', full_name='degiro_connector.trading.ProductSearch.RequestBonds.sort_columns', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sort_types', full_name='degiro_connector.trading.ProductSearch.RequestBonds.sort_types', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4175,
  serialized_end=4361,
)

_PRODUCTSEARCH_REQUESTETFS = _descriptor.Descriptor(
  name='RequestETFs',
  full_name='degiro_connector.trading.ProductSearch.RequestETFs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='popular_only', full_name='degiro_connector.trading.ProductSearch.RequestETFs.popular_only', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_aggregate_types', full_name='degiro_connector.trading.ProductSearch.RequestETFs.input_aggregate_types', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_aggregate_values', full_name='degiro_connector.trading.ProductSearch.RequestETFs.input_aggregate_values', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='search_text', full_name='degiro_connector.trading.ProductSearch.RequestETFs.search_text', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='degiro_connector.trading.ProductSearch.RequestETFs.offset', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='degiro_connector.trading.ProductSearch.RequestETFs.limit', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='require_total', full_name='degiro_connector.trading.ProductSearch.RequestETFs.require_total', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sort_columns', full_name='degiro_connector.trading.ProductSearch.RequestETFs.sort_columns', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sort_types', full_name='degiro_connector.trading.ProductSearch.RequestETFs.sort_types', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4364,
  serialized_end=4579,
)

_PRODUCTSEARCH_REQUESTFUNDS = _descriptor.Descriptor(
  name='RequestFunds',
  full_name='degiro_connector.trading.ProductSearch.RequestFunds',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='search_text', full_name='degiro_connector.trading.ProductSearch.RequestFunds.search_text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='degiro_connector.trading.ProductSearch.RequestFunds.offset', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='degiro_connector.trading.ProductSearch.RequestFunds.limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='require_total', full_name='degiro_connector.trading.ProductSearch.RequestFunds.require_total', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sort_columns', full_name='degiro_connector.trading.ProductSearch.RequestFunds.sort_columns', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sort_types', full_name='degiro_connector.trading.ProductSearch.RequestFunds.sort_types', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4582,
  serialized_end=4713,
)

_PRODUCTSEARCH_REQUESTFUTURES = _descriptor.Descriptor(
  name='RequestFutures',
  full_name='degiro_connector.trading.ProductSearch.RequestFutures',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='future_exchange_id', full_name='degiro_connector.trading.ProductSearch.RequestFutures.future_exchange_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='underlying_isin', full_name='degiro_connector.trading.ProductSearch.RequestFutures.underlying_isin', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='search_text', full_name='degiro_connector.trading.ProductSearch.RequestFutures.search_text', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='degiro_connector.trading.ProductSearch.RequestFutures.offset', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='degiro_connector.trading.ProductSearch.RequestFutures.limit', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='require_total', full_name='degiro_connector.trading.ProductSearch.RequestFutures.require_total', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sort_columns', full_name='degiro_connector.trading.ProductSearch.RequestFutures.sort_columns', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sort_types', full_name='degiro_connector.trading.ProductSearch.RequestFutures.sort_types', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4716,
  serialized_end=4902,
)

_PRODUCTSEARCH_REQUESTLEVERAGEDS = _descriptor.Descriptor(
  name='RequestLeverageds',
  full_name='degiro_connector.trading.ProductSearch.RequestLeverageds',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='popular_only', full_name='degiro_connector.trading.ProductSearch.RequestLeverageds.popular_only', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_aggregate_types', full_name='degiro_connector.trading.ProductSearch.RequestLeverageds.input_aggregate_types', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_aggregate_values', full_name='degiro_connector.trading.ProductSearch.RequestLeverageds.input_aggregate_values', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='search_text', full_name='degiro_connector.trading.ProductSearch.RequestLeverageds.search_text', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='degiro_connector.trading.ProductSearch.RequestLeverageds.offset', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='degiro_connector.trading.ProductSearch.RequestLeverageds.limit', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='require_total', full_name='degiro_connector.trading.ProductSearch.RequestLeverageds.require_total', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sort_columns', full_name='degiro_connector.trading.ProductSearch.RequestLeverageds.sort_columns', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sort_types', full_name='degiro_connector.trading.ProductSearch.RequestLeverageds.sort_types', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4905,
  serialized_end=5126,
)

_PRODUCTSEARCH_REQUESTLOOKUP = _descriptor.Descriptor(
  name='RequestLookup',
  full_name='degiro_connector.trading.ProductSearch.RequestLookup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='search_text', full_name='degiro_connector.trading.ProductSearch.RequestLookup.search_text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='degiro_connector.trading.ProductSearch.RequestLookup.limit', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='degiro_connector.trading.ProductSearch.RequestLookup.offset', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='product_type_id', full_name='degiro_connector.trading.ProductSearch.RequestLookup.product_type_id', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5128,
  serialized_end=5220,
)

_PRODUCTSEARCH_REQUESTOPTIONS = _descriptor.Descriptor(
  name='RequestOptions',
  full_name='degiro_connector.trading.ProductSearch.RequestOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input_aggregate_types', full_name='degiro_connector.trading.ProductSearch.RequestOptions.input_aggregate_types', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_aggregate_values', full_name='degiro_connector.trading.ProductSearch.RequestOptions.input_aggregate_values', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='option_exchange_id', full_name='degiro_connector.trading.ProductSearch.RequestOptions.option_exchange_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='underlying_isin', full_name='degiro_connector.trading.ProductSearch.RequestOptions.underlying_isin', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='search_text', full_name='degiro_connector.trading.ProductSearch.RequestOptions.search_text', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='degiro_connector.trading.ProductSearch.RequestOptions.offset', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='degiro_connector.trading.ProductSearch.RequestOptions.limit', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='require_total', full_name='degiro_connector.trading.ProductSearch.RequestOptions.require_total', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sort_columns', full_name='degiro_connector.trading.ProductSearch.RequestOptions.sort_columns', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sort_types', full_name='degiro_connector.trading.ProductSearch.RequestOptions.sort_types', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5223,
  serialized_end=5472,
)

_PRODUCTSEARCH_REQUESTSTOCKS = _descriptor.Descriptor(
  name='RequestStocks',
  full_name='degiro_connector.trading.ProductSearch.RequestStocks',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_in_us_green_list', full_name='degiro_connector.trading.ProductSearch.RequestStocks.is_in_us_green_list', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index_id', full_name='degiro_connector.trading.ProductSearch.RequestStocks.index_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='degiro_connector.trading.ProductSearch.RequestStocks.exchange_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stock_country_id', full_name='degiro_connector.trading.ProductSearch.RequestStocks.stock_country_id', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='search_text', full_name='degiro_connector.trading.ProductSearch.RequestStocks.search_text', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='degiro_connector.trading.ProductSearch.RequestStocks.offset', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='degiro_connector.trading.ProductSearch.RequestStocks.limit', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='require_total', full_name='degiro_connector.trading.ProductSearch.RequestStocks.require_total', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sort_columns', full_name='degiro_connector.trading.ProductSearch.RequestStocks.sort_columns', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sort_types', full_name='degiro_connector.trading.ProductSearch.RequestStocks.sort_types', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5475,
  serialized_end=5701,
)

_PRODUCTSEARCH_REQUESTWARRANTS = _descriptor.Descriptor(
  name='RequestWarrants',
  full_name='degiro_connector.trading.ProductSearch.RequestWarrants',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='search_text', full_name='degiro_connector.trading.ProductSearch.RequestWarrants.search_text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='degiro_connector.trading.ProductSearch.RequestWarrants.offset', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='degiro_connector.trading.ProductSearch.RequestWarrants.limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='require_total', full_name='degiro_connector.trading.ProductSearch.RequestWarrants.require_total', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sort_columns', full_name='degiro_connector.trading.ProductSearch.RequestWarrants.sort_columns', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sort_types', full_name='degiro_connector.trading.ProductSearch.RequestWarrants.sort_types', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5704,
  serialized_end=5838,
)

_PRODUCTSEARCH = _descriptor.Descriptor(
  name='ProductSearch',
  full_name='degiro_connector.trading.ProductSearch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='degiro_connector.trading.ProductSearch.offset', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='products', full_name='degiro_connector.trading.ProductSearch.products', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_datetime', full_name='degiro_connector.trading.ProductSearch.response_datetime', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total', full_name='degiro_connector.trading.ProductSearch.total', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PRODUCTSEARCH_CONFIG, _PRODUCTSEARCH_REQUESTBONDS, _PRODUCTSEARCH_REQUESTETFS, _PRODUCTSEARCH_REQUESTFUNDS, _PRODUCTSEARCH_REQUESTFUTURES, _PRODUCTSEARCH_REQUESTLEVERAGEDS, _PRODUCTSEARCH_REQUESTLOOKUP, _PRODUCTSEARCH_REQUESTOPTIONS, _PRODUCTSEARCH_REQUESTSTOCKS, _PRODUCTSEARCH_REQUESTWARRANTS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3977,
  serialized_end=5838,
)


_FAVOURITES_LIST = _descriptor.Descriptor(
  name='List',
  full_name='degiro_connector.trading.Favourites.List',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='degiro_connector.trading.Favourites.List.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='degiro_connector.trading.Favourites.List.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_default', full_name='degiro_connector.trading.Favourites.List.is_default', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='product_ids', full_name='degiro_connector.trading.Favourites.List.product_ids', index=3,
      number=4, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5969,
  serialized_end=6042,
)

_FAVOURITES = _descriptor.Descriptor(
  name='Favourites',
  full_name='degiro_connector.trading.Favourites',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='degiro_connector.trading.Favourites.values', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_datetime', full_name='degiro_connector.trading.Favourites.response_datetime', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FAVOURITES_LIST, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5841,
  serialized_end=6042,
)


_PRODUCTSINFO_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='degiro_connector.trading.ProductsInfo.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='products', full_name='degiro_connector.trading.ProductsInfo.Request.products', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6101,
  serialized_end=6128,
)

_PRODUCTSINFO = _descriptor.Descriptor(
  name='ProductsInfo',
  full_name='degiro_connector.trading.ProductsInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='degiro_connector.trading.ProductsInfo.values', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PRODUCTSINFO_REQUEST, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6044,
  serialized_end=6128,
)


_COMPANYRATIOS = _descriptor.Descriptor(
  name='CompanyRatios',
  full_name='degiro_connector.trading.CompanyRatios',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='degiro_connector.trading.CompanyRatios.values', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6130,
  serialized_end=6186,
)


_COMPANYPROFILE = _descriptor.Descriptor(
  name='CompanyProfile',
  full_name='degiro_connector.trading.CompanyProfile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='degiro_connector.trading.CompanyProfile.values', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6188,
  serialized_end=6245,
)


_FINANCIALSTATEMENTS = _descriptor.Descriptor(
  name='FinancialStatements',
  full_name='degiro_connector.trading.FinancialStatements',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='degiro_connector.trading.FinancialStatements.values', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6247,
  serialized_end=6309,
)


_LATESTNEWS_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='degiro_connector.trading.LatestNews.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='degiro_connector.trading.LatestNews.Request.offset', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='languages', full_name='degiro_connector.trading.LatestNews.Request.languages', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='degiro_connector.trading.LatestNews.Request.limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6397,
  serialized_end=6456,
)

_LATESTNEWS = _descriptor.Descriptor(
  name='LatestNews',
  full_name='degiro_connector.trading.LatestNews',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='degiro_connector.trading.LatestNews.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='degiro_connector.trading.LatestNews.offset', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total', full_name='degiro_connector.trading.LatestNews.total', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LATESTNEWS_REQUEST, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6312,
  serialized_end=6456,
)


_TOPNEWSPREVIEW = _descriptor.Descriptor(
  name='TopNewsPreview',
  full_name='degiro_connector.trading.TopNewsPreview',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='degiro_connector.trading.TopNewsPreview.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='degiro_connector.trading.TopNewsPreview.offset', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total', full_name='degiro_connector.trading.TopNewsPreview.total', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6458,
  serialized_end=6545,
)


_NEWSBYCOMPANY_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='degiro_connector.trading.NewsByCompany.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='isin', full_name='degiro_connector.trading.NewsByCompany.Request.isin', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='degiro_connector.trading.NewsByCompany.Request.limit', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='degiro_connector.trading.NewsByCompany.Request.offset', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='languages', full_name='degiro_connector.trading.NewsByCompany.Request.languages', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6636,
  serialized_end=6709,
)

_NEWSBYCOMPANY = _descriptor.Descriptor(
  name='NewsByCompany',
  full_name='degiro_connector.trading.NewsByCompany',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='degiro_connector.trading.NewsByCompany.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='degiro_connector.trading.NewsByCompany.offset', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total', full_name='degiro_connector.trading.NewsByCompany.total', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_NEWSBYCOMPANY_REQUEST, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6548,
  serialized_end=6709,
)


_CASHACCOUNTREPORT_REQUEST_DATE = _descriptor.Descriptor(
  name='Date',
  full_name='degiro_connector.trading.CashAccountReport.Request.Date',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='year', full_name='degiro_connector.trading.CashAccountReport.Request.Date.year', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='month', full_name='degiro_connector.trading.CashAccountReport.Request.Date.month', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='day', full_name='degiro_connector.trading.CashAccountReport.Request.Date.day', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3225,
  serialized_end=3273,
)

_CASHACCOUNTREPORT_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='degiro_connector.trading.CashAccountReport.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='format', full_name='degiro_connector.trading.CashAccountReport.Request.format', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='country', full_name='degiro_connector.trading.CashAccountReport.Request.country', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lang', full_name='degiro_connector.trading.CashAccountReport.Request.lang', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_date', full_name='degiro_connector.trading.CashAccountReport.Request.from_date', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_date', full_name='degiro_connector.trading.CashAccountReport.Request.to_date', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CASHACCOUNTREPORT_REQUEST_DATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6874,
  serialized_end=7184,
)

_CASHACCOUNTREPORT = _descriptor.Descriptor(
  name='CashAccountReport',
  full_name='degiro_connector.trading.CashAccountReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='degiro_connector.trading.CashAccountReport.content', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format', full_name='degiro_connector.trading.CashAccountReport.format', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_datetime', full_name='degiro_connector.trading.CashAccountReport.response_datetime', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CASHACCOUNTREPORT_REQUEST, ],
  enum_types=[
    _CASHACCOUNTREPORT_FORMAT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6712,
  serialized_end=7231,
)


_AGENDA_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='degiro_connector.trading.Agenda.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='calendar_type', full_name='degiro_connector.trading.Agenda.Request.calendar_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='degiro_connector.trading.Agenda.Request.offset', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='degiro_connector.trading.Agenda.Request.limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_by_desc', full_name='degiro_connector.trading.Agenda.Request.order_by_desc', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_date', full_name='degiro_connector.trading.Agenda.Request.start_date', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_date', full_name='degiro_connector.trading.Agenda.Request.end_date', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='company_name', full_name='degiro_connector.trading.Agenda.Request.company_name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='countries', full_name='degiro_connector.trading.Agenda.Request.countries', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='classifications', full_name='degiro_connector.trading.Agenda.Request.classifications', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='units', full_name='degiro_connector.trading.Agenda.Request.units', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7441,
  serialized_end=7749,
)

_AGENDA = _descriptor.Descriptor(
  name='Agenda',
  full_name='degiro_connector.trading.Agenda',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='calendar_type', full_name='degiro_connector.trading.Agenda.calendar_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='degiro_connector.trading.Agenda.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='degiro_connector.trading.Agenda.offset', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total', full_name='degiro_connector.trading.Agenda.total', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_datetime', full_name='degiro_connector.trading.Agenda.response_datetime', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_AGENDA_REQUEST, ],
  enum_types=[
    _AGENDA_CALENDARTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7234,
  serialized_end=7895,
)


_ESTIMATESSUMMARIES = _descriptor.Descriptor(
  name='EstimatesSummaries',
  full_name='degiro_connector.trading.EstimatesSummaries',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='annual', full_name='degiro_connector.trading.EstimatesSummaries.annual', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currency', full_name='degiro_connector.trading.EstimatesSummaries.currency', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interim', full_name='degiro_connector.trading.EstimatesSummaries.interim', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastRetrieved', full_name='degiro_connector.trading.EstimatesSummaries.lastRetrieved', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastUpdated', full_name='degiro_connector.trading.EstimatesSummaries.lastUpdated', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preferredMeasure', full_name='degiro_connector.trading.EstimatesSummaries.preferredMeasure', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ric', full_name='degiro_connector.trading.EstimatesSummaries.ric', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7898,
  serialized_end=8102,
)


_POSITIONREPORT_REQUEST_DATE = _descriptor.Descriptor(
  name='Date',
  full_name='degiro_connector.trading.PositionReport.Request.Date',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='year', full_name='degiro_connector.trading.PositionReport.Request.Date.year', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='month', full_name='degiro_connector.trading.PositionReport.Request.Date.month', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='day', full_name='degiro_connector.trading.PositionReport.Request.Date.day', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3225,
  serialized_end=3273,
)

_POSITIONREPORT_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='degiro_connector.trading.PositionReport.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='format', full_name='degiro_connector.trading.PositionReport.Request.format', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='country', full_name='degiro_connector.trading.PositionReport.Request.country', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lang', full_name='degiro_connector.trading.PositionReport.Request.lang', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_date', full_name='degiro_connector.trading.PositionReport.Request.to_date', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_POSITIONREPORT_REQUEST_DATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8261,
  serialized_end=8488,
)

_POSITIONREPORT = _descriptor.Descriptor(
  name='PositionReport',
  full_name='degiro_connector.trading.PositionReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='degiro_connector.trading.PositionReport.content', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format', full_name='degiro_connector.trading.PositionReport.format', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_datetime', full_name='degiro_connector.trading.PositionReport.response_datetime', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_POSITIONREPORT_REQUEST, ],
  enum_types=[
    _POSITIONREPORT_FORMAT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8105,
  serialized_end=8535,
)

_CREDENTIALS.oneofs_by_name['oneof_2fa'].fields.append(
  _CREDENTIALS.fields_by_name['totp_secret_key'])
_CREDENTIALS.fields_by_name['totp_secret_key'].containing_oneof = _CREDENTIALS.oneofs_by_name['oneof_2fa']
_CREDENTIALS.oneofs_by_name['oneof_2fa'].fields.append(
  _CREDENTIALS.fields_by_name['one_time_password'])
_CREDENTIALS.fields_by_name['one_time_password'].containing_oneof = _CREDENTIALS.oneofs_by_name['oneof_2fa']
_ORDER_CHECKINGRESPONSE.fields_by_name['response_datetime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ORDER_CHECKINGRESPONSE.fields_by_name['transaction_fees'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_ORDER_CHECKINGRESPONSE.fields_by_name['transaction_opposite_fees'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_ORDER_CHECKINGRESPONSE.fields_by_name['transaction_taxes'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_ORDER_CHECKINGRESPONSE.fields_by_name['transaction_auto_fx_surcharges'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_ORDER_CHECKINGRESPONSE.fields_by_name['transaction_auto_fx_opposite_surcharges'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_ORDER_CHECKINGRESPONSE.containing_type = _ORDER
_ORDER_CONFIRMATIONRESPONSE.fields_by_name['response_datetime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ORDER_CONFIRMATIONRESPONSE.containing_type = _ORDER
_ORDER.fields_by_name['action'].enum_type = _ORDER_ACTION
_ORDER.fields_by_name['order_type'].enum_type = _ORDER_ORDERTYPE
_ORDER.fields_by_name['time_type'].enum_type = _ORDER_TIMETYPE
_ORDER_ACTION.containing_type = _ORDER
_ORDER_ORDERTYPE.containing_type = _ORDER
_ORDER_TIMETYPE.containing_type = _ORDER
_UPDATE_REQUEST.fields_by_name['option'].enum_type = _UPDATE_OPTION
_UPDATE_REQUEST.containing_type = _UPDATE
_UPDATE_REQUESTLIST.fields_by_name['values'].message_type = _UPDATE_REQUEST
_UPDATE_REQUESTLIST.containing_type = _UPDATE
_UPDATE_ALERTS.fields_by_name['values'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_UPDATE_ALERTS.containing_type = _UPDATE
_UPDATE_CASHFUNDS.fields_by_name['values'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_UPDATE_CASHFUNDS.containing_type = _UPDATE
_UPDATE_HISTORICALORDERS.fields_by_name['values'].message_type = _ORDER
_UPDATE_HISTORICALORDERS.containing_type = _UPDATE
_UPDATE_ORDERS.fields_by_name['values'].message_type = _ORDER
_UPDATE_ORDERS.containing_type = _UPDATE
_UPDATE_PORTFOLIO.fields_by_name['values'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_UPDATE_PORTFOLIO.containing_type = _UPDATE
_UPDATE_TOTALPORTFOLIO.fields_by_name['values'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_UPDATE_TOTALPORTFOLIO.containing_type = _UPDATE
_UPDATE_TRANSACTIONS.fields_by_name['values'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_UPDATE_TRANSACTIONS.containing_type = _UPDATE
_UPDATE.fields_by_name['response_datetime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_UPDATE.fields_by_name['alerts'].message_type = _UPDATE_ALERTS
_UPDATE.fields_by_name['cash_funds'].message_type = _UPDATE_CASHFUNDS
_UPDATE.fields_by_name['historical_orders'].message_type = _UPDATE_HISTORICALORDERS
_UPDATE.fields_by_name['orders'].message_type = _UPDATE_ORDERS
_UPDATE.fields_by_name['portfolio'].message_type = _UPDATE_PORTFOLIO
_UPDATE.fields_by_name['total_portfolio'].message_type = _UPDATE_TOTALPORTFOLIO
_UPDATE.fields_by_name['transactions'].message_type = _UPDATE_TRANSACTIONS
_UPDATE_OPTION.containing_type = _UPDATE
_ORDERSHISTORY_REQUEST_DATE.containing_type = _ORDERSHISTORY_REQUEST
_ORDERSHISTORY_REQUEST.fields_by_name['from_date'].message_type = _ORDERSHISTORY_REQUEST_DATE
_ORDERSHISTORY_REQUEST.fields_by_name['to_date'].message_type = _ORDERSHISTORY_REQUEST_DATE
_ORDERSHISTORY_REQUEST.containing_type = _ORDERSHISTORY
_ORDERSHISTORY.fields_by_name['values'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_ORDERSHISTORY.fields_by_name['response_datetime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TRANSACTIONSHISTORY_REQUEST_DATE.containing_type = _TRANSACTIONSHISTORY_REQUEST
_TRANSACTIONSHISTORY_REQUEST.fields_by_name['from_date'].message_type = _TRANSACTIONSHISTORY_REQUEST_DATE
_TRANSACTIONSHISTORY_REQUEST.fields_by_name['to_date'].message_type = _TRANSACTIONSHISTORY_REQUEST_DATE
_TRANSACTIONSHISTORY_REQUEST.containing_type = _TRANSACTIONSHISTORY
_TRANSACTIONSHISTORY.fields_by_name['values'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_TRANSACTIONSHISTORY.fields_by_name['response_datetime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ACCOUNTOVERVIEW_REQUEST_DATE.containing_type = _ACCOUNTOVERVIEW_REQUEST
_ACCOUNTOVERVIEW_REQUEST.fields_by_name['from_date'].message_type = _ACCOUNTOVERVIEW_REQUEST_DATE
_ACCOUNTOVERVIEW_REQUEST.fields_by_name['to_date'].message_type = _ACCOUNTOVERVIEW_REQUEST_DATE
_ACCOUNTOVERVIEW_REQUEST.containing_type = _ACCOUNTOVERVIEW
_ACCOUNTOVERVIEW.fields_by_name['values'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_ACCOUNTOVERVIEW.fields_by_name['response_datetime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PRODUCTSEARCH_CONFIG.fields_by_name['values'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_PRODUCTSEARCH_CONFIG.containing_type = _PRODUCTSEARCH
_PRODUCTSEARCH_REQUESTBONDS.containing_type = _PRODUCTSEARCH
_PRODUCTSEARCH_REQUESTETFS.containing_type = _PRODUCTSEARCH
_PRODUCTSEARCH_REQUESTFUNDS.containing_type = _PRODUCTSEARCH
_PRODUCTSEARCH_REQUESTFUTURES.containing_type = _PRODUCTSEARCH
_PRODUCTSEARCH_REQUESTLEVERAGEDS.containing_type = _PRODUCTSEARCH
_PRODUCTSEARCH_REQUESTLOOKUP.containing_type = _PRODUCTSEARCH
_PRODUCTSEARCH_REQUESTOPTIONS.containing_type = _PRODUCTSEARCH
_PRODUCTSEARCH_REQUESTSTOCKS.containing_type = _PRODUCTSEARCH
_PRODUCTSEARCH_REQUESTWARRANTS.containing_type = _PRODUCTSEARCH
_PRODUCTSEARCH.fields_by_name['products'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_PRODUCTSEARCH.fields_by_name['response_datetime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FAVOURITES_LIST.containing_type = _FAVOURITES
_FAVOURITES.fields_by_name['values'].message_type = _FAVOURITES_LIST
_FAVOURITES.fields_by_name['response_datetime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PRODUCTSINFO_REQUEST.containing_type = _PRODUCTSINFO
_PRODUCTSINFO.fields_by_name['values'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_COMPANYRATIOS.fields_by_name['values'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_COMPANYPROFILE.fields_by_name['values'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_FINANCIALSTATEMENTS.fields_by_name['values'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_LATESTNEWS_REQUEST.containing_type = _LATESTNEWS
_LATESTNEWS.fields_by_name['items'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_TOPNEWSPREVIEW.fields_by_name['items'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_NEWSBYCOMPANY_REQUEST.containing_type = _NEWSBYCOMPANY
_NEWSBYCOMPANY.fields_by_name['items'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_CASHACCOUNTREPORT_REQUEST_DATE.containing_type = _CASHACCOUNTREPORT_REQUEST
_CASHACCOUNTREPORT_REQUEST.fields_by_name['format'].enum_type = _CASHACCOUNTREPORT_FORMAT
_CASHACCOUNTREPORT_REQUEST.fields_by_name['from_date'].message_type = _CASHACCOUNTREPORT_REQUEST_DATE
_CASHACCOUNTREPORT_REQUEST.fields_by_name['to_date'].message_type = _CASHACCOUNTREPORT_REQUEST_DATE
_CASHACCOUNTREPORT_REQUEST.containing_type = _CASHACCOUNTREPORT
_CASHACCOUNTREPORT.fields_by_name['format'].enum_type = _CASHACCOUNTREPORT_FORMAT
_CASHACCOUNTREPORT.fields_by_name['response_datetime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CASHACCOUNTREPORT_FORMAT.containing_type = _CASHACCOUNTREPORT
_AGENDA_REQUEST.fields_by_name['calendar_type'].enum_type = _AGENDA_CALENDARTYPE
_AGENDA_REQUEST.fields_by_name['start_date'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_AGENDA_REQUEST.fields_by_name['end_date'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_AGENDA_REQUEST.containing_type = _AGENDA
_AGENDA.fields_by_name['calendar_type'].enum_type = _AGENDA_CALENDARTYPE
_AGENDA.fields_by_name['items'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_AGENDA.fields_by_name['response_datetime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_AGENDA_CALENDARTYPE.containing_type = _AGENDA
_ESTIMATESSUMMARIES.fields_by_name['annual'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_ESTIMATESSUMMARIES.fields_by_name['interim'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_POSITIONREPORT_REQUEST_DATE.containing_type = _POSITIONREPORT_REQUEST
_POSITIONREPORT_REQUEST.fields_by_name['format'].enum_type = _POSITIONREPORT_FORMAT
_POSITIONREPORT_REQUEST.fields_by_name['to_date'].message_type = _POSITIONREPORT_REQUEST_DATE
_POSITIONREPORT_REQUEST.containing_type = _POSITIONREPORT
_POSITIONREPORT.fields_by_name['format'].enum_type = _POSITIONREPORT_FORMAT
_POSITIONREPORT.fields_by_name['response_datetime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_POSITIONREPORT_FORMAT.containing_type = _POSITIONREPORT
DESCRIPTOR.message_types_by_name['Credentials'] = _CREDENTIALS
DESCRIPTOR.message_types_by_name['Order'] = _ORDER
DESCRIPTOR.message_types_by_name['Update'] = _UPDATE
DESCRIPTOR.message_types_by_name['OrdersHistory'] = _ORDERSHISTORY
DESCRIPTOR.message_types_by_name['TransactionsHistory'] = _TRANSACTIONSHISTORY
DESCRIPTOR.message_types_by_name['AccountOverview'] = _ACCOUNTOVERVIEW
DESCRIPTOR.message_types_by_name['ProductSearch'] = _PRODUCTSEARCH
DESCRIPTOR.message_types_by_name['Favourites'] = _FAVOURITES
DESCRIPTOR.message_types_by_name['ProductsInfo'] = _PRODUCTSINFO
DESCRIPTOR.message_types_by_name['CompanyRatios'] = _COMPANYRATIOS
DESCRIPTOR.message_types_by_name['CompanyProfile'] = _COMPANYPROFILE
DESCRIPTOR.message_types_by_name['FinancialStatements'] = _FINANCIALSTATEMENTS
DESCRIPTOR.message_types_by_name['LatestNews'] = _LATESTNEWS
DESCRIPTOR.message_types_by_name['TopNewsPreview'] = _TOPNEWSPREVIEW
DESCRIPTOR.message_types_by_name['NewsByCompany'] = _NEWSBYCOMPANY
DESCRIPTOR.message_types_by_name['CashAccountReport'] = _CASHACCOUNTREPORT
DESCRIPTOR.message_types_by_name['Agenda'] = _AGENDA
DESCRIPTOR.message_types_by_name['EstimatesSummaries'] = _ESTIMATESSUMMARIES
DESCRIPTOR.message_types_by_name['PositionReport'] = _POSITIONREPORT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Credentials = _reflection.GeneratedProtocolMessageType('Credentials', (_message.Message,), {
  'DESCRIPTOR' : _CREDENTIALS,
  '__module__' : 'degiro_connector.trading.models.trading_pb2'
  # @@protoc_insertion_point(class_scope:degiro_connector.trading.Credentials)
  })
_sym_db.RegisterMessage(Credentials)

Order = _reflection.GeneratedProtocolMessageType('Order', (_message.Message,), {

  'CheckingResponse' : _reflection.GeneratedProtocolMessageType('CheckingResponse', (_message.Message,), {
    'DESCRIPTOR' : _ORDER_CHECKINGRESPONSE,
    '__module__' : 'degiro_connector.trading.models.trading_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.trading.Order.CheckingResponse)
    })
  ,

  'ConfirmationResponse' : _reflection.GeneratedProtocolMessageType('ConfirmationResponse', (_message.Message,), {
    'DESCRIPTOR' : _ORDER_CONFIRMATIONRESPONSE,
    '__module__' : 'degiro_connector.trading.models.trading_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.trading.Order.ConfirmationResponse)
    })
  ,
  'DESCRIPTOR' : _ORDER,
  '__module__' : 'degiro_connector.trading.models.trading_pb2'
  # @@protoc_insertion_point(class_scope:degiro_connector.trading.Order)
  })
_sym_db.RegisterMessage(Order)
_sym_db.RegisterMessage(Order.CheckingResponse)
_sym_db.RegisterMessage(Order.ConfirmationResponse)

Update = _reflection.GeneratedProtocolMessageType('Update', (_message.Message,), {

  'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
    'DESCRIPTOR' : _UPDATE_REQUEST,
    '__module__' : 'degiro_connector.trading.models.trading_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.trading.Update.Request)
    })
  ,

  'RequestList' : _reflection.GeneratedProtocolMessageType('RequestList', (_message.Message,), {
    'DESCRIPTOR' : _UPDATE_REQUESTLIST,
    '__module__' : 'degiro_connector.trading.models.trading_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.trading.Update.RequestList)
    })
  ,

  'Alerts' : _reflection.GeneratedProtocolMessageType('Alerts', (_message.Message,), {
    'DESCRIPTOR' : _UPDATE_ALERTS,
    '__module__' : 'degiro_connector.trading.models.trading_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.trading.Update.Alerts)
    })
  ,

  'CashFunds' : _reflection.GeneratedProtocolMessageType('CashFunds', (_message.Message,), {
    'DESCRIPTOR' : _UPDATE_CASHFUNDS,
    '__module__' : 'degiro_connector.trading.models.trading_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.trading.Update.CashFunds)
    })
  ,

  'HistoricalOrders' : _reflection.GeneratedProtocolMessageType('HistoricalOrders', (_message.Message,), {
    'DESCRIPTOR' : _UPDATE_HISTORICALORDERS,
    '__module__' : 'degiro_connector.trading.models.trading_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.trading.Update.HistoricalOrders)
    })
  ,

  'Orders' : _reflection.GeneratedProtocolMessageType('Orders', (_message.Message,), {
    'DESCRIPTOR' : _UPDATE_ORDERS,
    '__module__' : 'degiro_connector.trading.models.trading_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.trading.Update.Orders)
    })
  ,

  'Portfolio' : _reflection.GeneratedProtocolMessageType('Portfolio', (_message.Message,), {
    'DESCRIPTOR' : _UPDATE_PORTFOLIO,
    '__module__' : 'degiro_connector.trading.models.trading_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.trading.Update.Portfolio)
    })
  ,

  'TotalPortfolio' : _reflection.GeneratedProtocolMessageType('TotalPortfolio', (_message.Message,), {
    'DESCRIPTOR' : _UPDATE_TOTALPORTFOLIO,
    '__module__' : 'degiro_connector.trading.models.trading_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.trading.Update.TotalPortfolio)
    })
  ,

  'Transactions' : _reflection.GeneratedProtocolMessageType('Transactions', (_message.Message,), {
    'DESCRIPTOR' : _UPDATE_TRANSACTIONS,
    '__module__' : 'degiro_connector.trading.models.trading_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.trading.Update.Transactions)
    })
  ,
  'DESCRIPTOR' : _UPDATE,
  '__module__' : 'degiro_connector.trading.models.trading_pb2'
  # @@protoc_insertion_point(class_scope:degiro_connector.trading.Update)
  })
_sym_db.RegisterMessage(Update)
_sym_db.RegisterMessage(Update.Request)
_sym_db.RegisterMessage(Update.RequestList)
_sym_db.RegisterMessage(Update.Alerts)
_sym_db.RegisterMessage(Update.CashFunds)
_sym_db.RegisterMessage(Update.HistoricalOrders)
_sym_db.RegisterMessage(Update.Orders)
_sym_db.RegisterMessage(Update.Portfolio)
_sym_db.RegisterMessage(Update.TotalPortfolio)
_sym_db.RegisterMessage(Update.Transactions)

OrdersHistory = _reflection.GeneratedProtocolMessageType('OrdersHistory', (_message.Message,), {

  'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {

    'Date' : _reflection.GeneratedProtocolMessageType('Date', (_message.Message,), {
      'DESCRIPTOR' : _ORDERSHISTORY_REQUEST_DATE,
      '__module__' : 'degiro_connector.trading.models.trading_pb2'
      # @@protoc_insertion_point(class_scope:degiro_connector.trading.OrdersHistory.Request.Date)
      })
    ,
    'DESCRIPTOR' : _ORDERSHISTORY_REQUEST,
    '__module__' : 'degiro_connector.trading.models.trading_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.trading.OrdersHistory.Request)
    })
  ,
  'DESCRIPTOR' : _ORDERSHISTORY,
  '__module__' : 'degiro_connector.trading.models.trading_pb2'
  # @@protoc_insertion_point(class_scope:degiro_connector.trading.OrdersHistory)
  })
_sym_db.RegisterMessage(OrdersHistory)
_sym_db.RegisterMessage(OrdersHistory.Request)
_sym_db.RegisterMessage(OrdersHistory.Request.Date)

TransactionsHistory = _reflection.GeneratedProtocolMessageType('TransactionsHistory', (_message.Message,), {

  'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {

    'Date' : _reflection.GeneratedProtocolMessageType('Date', (_message.Message,), {
      'DESCRIPTOR' : _TRANSACTIONSHISTORY_REQUEST_DATE,
      '__module__' : 'degiro_connector.trading.models.trading_pb2'
      # @@protoc_insertion_point(class_scope:degiro_connector.trading.TransactionsHistory.Request.Date)
      })
    ,
    'DESCRIPTOR' : _TRANSACTIONSHISTORY_REQUEST,
    '__module__' : 'degiro_connector.trading.models.trading_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.trading.TransactionsHistory.Request)
    })
  ,
  'DESCRIPTOR' : _TRANSACTIONSHISTORY,
  '__module__' : 'degiro_connector.trading.models.trading_pb2'
  # @@protoc_insertion_point(class_scope:degiro_connector.trading.TransactionsHistory)
  })
_sym_db.RegisterMessage(TransactionsHistory)
_sym_db.RegisterMessage(TransactionsHistory.Request)
_sym_db.RegisterMessage(TransactionsHistory.Request.Date)

AccountOverview = _reflection.GeneratedProtocolMessageType('AccountOverview', (_message.Message,), {

  'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {

    'Date' : _reflection.GeneratedProtocolMessageType('Date', (_message.Message,), {
      'DESCRIPTOR' : _ACCOUNTOVERVIEW_REQUEST_DATE,
      '__module__' : 'degiro_connector.trading.models.trading_pb2'
      # @@protoc_insertion_point(class_scope:degiro_connector.trading.AccountOverview.Request.Date)
      })
    ,
    'DESCRIPTOR' : _ACCOUNTOVERVIEW_REQUEST,
    '__module__' : 'degiro_connector.trading.models.trading_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.trading.AccountOverview.Request)
    })
  ,
  'DESCRIPTOR' : _ACCOUNTOVERVIEW,
  '__module__' : 'degiro_connector.trading.models.trading_pb2'
  # @@protoc_insertion_point(class_scope:degiro_connector.trading.AccountOverview)
  })
_sym_db.RegisterMessage(AccountOverview)
_sym_db.RegisterMessage(AccountOverview.Request)
_sym_db.RegisterMessage(AccountOverview.Request.Date)

ProductSearch = _reflection.GeneratedProtocolMessageType('ProductSearch', (_message.Message,), {

  'Config' : _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
    'DESCRIPTOR' : _PRODUCTSEARCH_CONFIG,
    '__module__' : 'degiro_connector.trading.models.trading_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.trading.ProductSearch.Config)
    })
  ,

  'RequestBonds' : _reflection.GeneratedProtocolMessageType('RequestBonds', (_message.Message,), {
    'DESCRIPTOR' : _PRODUCTSEARCH_REQUESTBONDS,
    '__module__' : 'degiro_connector.trading.models.trading_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.trading.ProductSearch.RequestBonds)
    })
  ,

  'RequestETFs' : _reflection.GeneratedProtocolMessageType('RequestETFs', (_message.Message,), {
    'DESCRIPTOR' : _PRODUCTSEARCH_REQUESTETFS,
    '__module__' : 'degiro_connector.trading.models.trading_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.trading.ProductSearch.RequestETFs)
    })
  ,

  'RequestFunds' : _reflection.GeneratedProtocolMessageType('RequestFunds', (_message.Message,), {
    'DESCRIPTOR' : _PRODUCTSEARCH_REQUESTFUNDS,
    '__module__' : 'degiro_connector.trading.models.trading_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.trading.ProductSearch.RequestFunds)
    })
  ,

  'RequestFutures' : _reflection.GeneratedProtocolMessageType('RequestFutures', (_message.Message,), {
    'DESCRIPTOR' : _PRODUCTSEARCH_REQUESTFUTURES,
    '__module__' : 'degiro_connector.trading.models.trading_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.trading.ProductSearch.RequestFutures)
    })
  ,

  'RequestLeverageds' : _reflection.GeneratedProtocolMessageType('RequestLeverageds', (_message.Message,), {
    'DESCRIPTOR' : _PRODUCTSEARCH_REQUESTLEVERAGEDS,
    '__module__' : 'degiro_connector.trading.models.trading_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.trading.ProductSearch.RequestLeverageds)
    })
  ,

  'RequestLookup' : _reflection.GeneratedProtocolMessageType('RequestLookup', (_message.Message,), {
    'DESCRIPTOR' : _PRODUCTSEARCH_REQUESTLOOKUP,
    '__module__' : 'degiro_connector.trading.models.trading_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.trading.ProductSearch.RequestLookup)
    })
  ,

  'RequestOptions' : _reflection.GeneratedProtocolMessageType('RequestOptions', (_message.Message,), {
    'DESCRIPTOR' : _PRODUCTSEARCH_REQUESTOPTIONS,
    '__module__' : 'degiro_connector.trading.models.trading_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.trading.ProductSearch.RequestOptions)
    })
  ,

  'RequestStocks' : _reflection.GeneratedProtocolMessageType('RequestStocks', (_message.Message,), {
    'DESCRIPTOR' : _PRODUCTSEARCH_REQUESTSTOCKS,
    '__module__' : 'degiro_connector.trading.models.trading_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.trading.ProductSearch.RequestStocks)
    })
  ,

  'RequestWarrants' : _reflection.GeneratedProtocolMessageType('RequestWarrants', (_message.Message,), {
    'DESCRIPTOR' : _PRODUCTSEARCH_REQUESTWARRANTS,
    '__module__' : 'degiro_connector.trading.models.trading_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.trading.ProductSearch.RequestWarrants)
    })
  ,
  'DESCRIPTOR' : _PRODUCTSEARCH,
  '__module__' : 'degiro_connector.trading.models.trading_pb2'
  # @@protoc_insertion_point(class_scope:degiro_connector.trading.ProductSearch)
  })
_sym_db.RegisterMessage(ProductSearch)
_sym_db.RegisterMessage(ProductSearch.Config)
_sym_db.RegisterMessage(ProductSearch.RequestBonds)
_sym_db.RegisterMessage(ProductSearch.RequestETFs)
_sym_db.RegisterMessage(ProductSearch.RequestFunds)
_sym_db.RegisterMessage(ProductSearch.RequestFutures)
_sym_db.RegisterMessage(ProductSearch.RequestLeverageds)
_sym_db.RegisterMessage(ProductSearch.RequestLookup)
_sym_db.RegisterMessage(ProductSearch.RequestOptions)
_sym_db.RegisterMessage(ProductSearch.RequestStocks)
_sym_db.RegisterMessage(ProductSearch.RequestWarrants)

Favourites = _reflection.GeneratedProtocolMessageType('Favourites', (_message.Message,), {

  'List' : _reflection.GeneratedProtocolMessageType('List', (_message.Message,), {
    'DESCRIPTOR' : _FAVOURITES_LIST,
    '__module__' : 'degiro_connector.trading.models.trading_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.trading.Favourites.List)
    })
  ,
  'DESCRIPTOR' : _FAVOURITES,
  '__module__' : 'degiro_connector.trading.models.trading_pb2'
  # @@protoc_insertion_point(class_scope:degiro_connector.trading.Favourites)
  })
_sym_db.RegisterMessage(Favourites)
_sym_db.RegisterMessage(Favourites.List)

ProductsInfo = _reflection.GeneratedProtocolMessageType('ProductsInfo', (_message.Message,), {

  'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
    'DESCRIPTOR' : _PRODUCTSINFO_REQUEST,
    '__module__' : 'degiro_connector.trading.models.trading_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.trading.ProductsInfo.Request)
    })
  ,
  'DESCRIPTOR' : _PRODUCTSINFO,
  '__module__' : 'degiro_connector.trading.models.trading_pb2'
  # @@protoc_insertion_point(class_scope:degiro_connector.trading.ProductsInfo)
  })
_sym_db.RegisterMessage(ProductsInfo)
_sym_db.RegisterMessage(ProductsInfo.Request)

CompanyRatios = _reflection.GeneratedProtocolMessageType('CompanyRatios', (_message.Message,), {
  'DESCRIPTOR' : _COMPANYRATIOS,
  '__module__' : 'degiro_connector.trading.models.trading_pb2'
  # @@protoc_insertion_point(class_scope:degiro_connector.trading.CompanyRatios)
  })
_sym_db.RegisterMessage(CompanyRatios)

CompanyProfile = _reflection.GeneratedProtocolMessageType('CompanyProfile', (_message.Message,), {
  'DESCRIPTOR' : _COMPANYPROFILE,
  '__module__' : 'degiro_connector.trading.models.trading_pb2'
  # @@protoc_insertion_point(class_scope:degiro_connector.trading.CompanyProfile)
  })
_sym_db.RegisterMessage(CompanyProfile)

FinancialStatements = _reflection.GeneratedProtocolMessageType('FinancialStatements', (_message.Message,), {
  'DESCRIPTOR' : _FINANCIALSTATEMENTS,
  '__module__' : 'degiro_connector.trading.models.trading_pb2'
  # @@protoc_insertion_point(class_scope:degiro_connector.trading.FinancialStatements)
  })
_sym_db.RegisterMessage(FinancialStatements)

LatestNews = _reflection.GeneratedProtocolMessageType('LatestNews', (_message.Message,), {

  'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
    'DESCRIPTOR' : _LATESTNEWS_REQUEST,
    '__module__' : 'degiro_connector.trading.models.trading_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.trading.LatestNews.Request)
    })
  ,
  'DESCRIPTOR' : _LATESTNEWS,
  '__module__' : 'degiro_connector.trading.models.trading_pb2'
  # @@protoc_insertion_point(class_scope:degiro_connector.trading.LatestNews)
  })
_sym_db.RegisterMessage(LatestNews)
_sym_db.RegisterMessage(LatestNews.Request)

TopNewsPreview = _reflection.GeneratedProtocolMessageType('TopNewsPreview', (_message.Message,), {
  'DESCRIPTOR' : _TOPNEWSPREVIEW,
  '__module__' : 'degiro_connector.trading.models.trading_pb2'
  # @@protoc_insertion_point(class_scope:degiro_connector.trading.TopNewsPreview)
  })
_sym_db.RegisterMessage(TopNewsPreview)

NewsByCompany = _reflection.GeneratedProtocolMessageType('NewsByCompany', (_message.Message,), {

  'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
    'DESCRIPTOR' : _NEWSBYCOMPANY_REQUEST,
    '__module__' : 'degiro_connector.trading.models.trading_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.trading.NewsByCompany.Request)
    })
  ,
  'DESCRIPTOR' : _NEWSBYCOMPANY,
  '__module__' : 'degiro_connector.trading.models.trading_pb2'
  # @@protoc_insertion_point(class_scope:degiro_connector.trading.NewsByCompany)
  })
_sym_db.RegisterMessage(NewsByCompany)
_sym_db.RegisterMessage(NewsByCompany.Request)

CashAccountReport = _reflection.GeneratedProtocolMessageType('CashAccountReport', (_message.Message,), {

  'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {

    'Date' : _reflection.GeneratedProtocolMessageType('Date', (_message.Message,), {
      'DESCRIPTOR' : _CASHACCOUNTREPORT_REQUEST_DATE,
      '__module__' : 'degiro_connector.trading.models.trading_pb2'
      # @@protoc_insertion_point(class_scope:degiro_connector.trading.CashAccountReport.Request.Date)
      })
    ,
    'DESCRIPTOR' : _CASHACCOUNTREPORT_REQUEST,
    '__module__' : 'degiro_connector.trading.models.trading_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.trading.CashAccountReport.Request)
    })
  ,
  'DESCRIPTOR' : _CASHACCOUNTREPORT,
  '__module__' : 'degiro_connector.trading.models.trading_pb2'
  # @@protoc_insertion_point(class_scope:degiro_connector.trading.CashAccountReport)
  })
_sym_db.RegisterMessage(CashAccountReport)
_sym_db.RegisterMessage(CashAccountReport.Request)
_sym_db.RegisterMessage(CashAccountReport.Request.Date)

Agenda = _reflection.GeneratedProtocolMessageType('Agenda', (_message.Message,), {

  'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
    'DESCRIPTOR' : _AGENDA_REQUEST,
    '__module__' : 'degiro_connector.trading.models.trading_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.trading.Agenda.Request)
    })
  ,
  'DESCRIPTOR' : _AGENDA,
  '__module__' : 'degiro_connector.trading.models.trading_pb2'
  # @@protoc_insertion_point(class_scope:degiro_connector.trading.Agenda)
  })
_sym_db.RegisterMessage(Agenda)
_sym_db.RegisterMessage(Agenda.Request)

EstimatesSummaries = _reflection.GeneratedProtocolMessageType('EstimatesSummaries', (_message.Message,), {
  'DESCRIPTOR' : _ESTIMATESSUMMARIES,
  '__module__' : 'degiro_connector.trading.models.trading_pb2'
  # @@protoc_insertion_point(class_scope:degiro_connector.trading.EstimatesSummaries)
  })
_sym_db.RegisterMessage(EstimatesSummaries)

PositionReport = _reflection.GeneratedProtocolMessageType('PositionReport', (_message.Message,), {

  'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {

    'Date' : _reflection.GeneratedProtocolMessageType('Date', (_message.Message,), {
      'DESCRIPTOR' : _POSITIONREPORT_REQUEST_DATE,
      '__module__' : 'degiro_connector.trading.models.trading_pb2'
      # @@protoc_insertion_point(class_scope:degiro_connector.trading.PositionReport.Request.Date)
      })
    ,
    'DESCRIPTOR' : _POSITIONREPORT_REQUEST,
    '__module__' : 'degiro_connector.trading.models.trading_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.trading.PositionReport.Request)
    })
  ,
  'DESCRIPTOR' : _POSITIONREPORT,
  '__module__' : 'degiro_connector.trading.models.trading_pb2'
  # @@protoc_insertion_point(class_scope:degiro_connector.trading.PositionReport)
  })
_sym_db.RegisterMessage(PositionReport)
_sym_db.RegisterMessage(PositionReport.Request)
_sym_db.RegisterMessage(PositionReport.Request.Date)


# @@protoc_insertion_point(module_scope)
